package com.ms.stock.utils;

import android.content.Context;

import com.android.volley.AuthFailureError;
import com.android.volley.NetworkResponse;
import com.android.volley.ParseError;
import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.HttpHeaderParser;
import com.android.volley.toolbox.JsonObjectRequest;
import com.android.volley.toolbox.Volley;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.UnsupportedEncodingException;
import java.util.HashMap;
import java.util.Map;

public class VolleyUtil {
	public static void postJsonData(final Context context, String url, JSONObject params,
									final PostJsonListener postJsonListener) {
		try {
			// 1.创建请求队列
			RequestQueue volleyRequestQueue = Volley.newRequestQueue(context);
			JsonObjectRequest jsonObjectRequest = new JsonObjectRequest(Request.Method.POST, url, params,
					new Response.Listener<JSONObject>() {
						public void onResponse(JSONObject jsonResult) {
							postJsonListener.onSuccee(jsonResult);
						}
					}, new Response.ErrorListener() {
				public void onErrorResponse(VolleyError volleyError) {
					postJsonListener.onFail(volleyError);
				}
			}) {
				@Override
				public Map<String, String> getHeaders() throws AuthFailureError {
					HashMap<String, String> header = new HashMap<String, String>();
					header.put("Cookie", "v=1.0;token="+MyApplication.getInstance().getToken());
					return header;
				}
				@Override
				protected Map<String, String> getParams() throws AuthFailureError {
					HashMap<String, String> param = new HashMap<String, String>();
					param.put("Cookie", "v=1.0;token="+MyApplication.getInstance().getToken());
					return param;
				}

				protected Response<JSONObject> parseNetworkResponse(NetworkResponse arg0) {
					try {
						JSONObject jsonObject = new JSONObject(new String(arg0.data, "UTF-8"));
						return Response.success(jsonObject, HttpHeaderParser.parseCacheHeaders(arg0));
					} catch (UnsupportedEncodingException e) {
						return Response.error(new ParseError(e));
					} catch (Exception je) {
						return Response.error(new ParseError(je));
					}
				}


			};

			// 4.请求对象放入请求队列
			volleyRequestQueue.add(jsonObjectRequest);
		} catch (Exception e) {
		}
	}

	/**
	 * 返回的成功码
	 * @param jsonResult
	 * @return
	 */
	public static int getResponedCode(JSONObject jsonResult) {
		try {
			String dateText = jsonResult.getString("ret");
			int code = Integer.parseInt(dateText);
			return code;
		} catch (JSONException e) {
			e.printStackTrace();
		}
		return -1;
	}

	public interface PostJsonListener {
		void onSuccee(JSONObject jsonResult);

		void onFail(VolleyError volleyError);
	}

}
